@@ -316,7 +316,7 @@ class MessageBus:
         return ReleaseNameReply(reply.body[0])
 
     async def get_proxy_object(self, bus_name: str, path: str,
-                               introspection: Union[intr.Node, str, ET.Element]) -> ProxyObject:
+                               introspection: Union[intr.Node, str, ET.Element] = None) -> ProxyObject:
         """Get a proxy object for the path exported on the bus that owns the
         name. The object is expected to export the interfaces and nodes
         specified in the introspection data.
@@ -344,6 +344,9 @@ class MessageBus:
 
         await self._init_high_level_client()
 
+        if introspection is None:
+            introspection = await self.introspect(bus_name, path)
+
         return self._ProxyObject(bus_name, path, introspection, self)
 
     def next_serial(self) -> int:
